library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

entity mac is
    Port ( clk        : in  STD_LOGIC;
           rst        : in  STD_LOGIC;
           sum_rst    : in std_logic;
           enable     : in std_logic;
           smpl          : in  signed(10 downto 0); -- 11-bit input a
           coef          : in  signed(10 downto 0); -- 11-bit input b
           acc_out    : inout signed(28 downto 0) -- 29-bit acc output
           );
end entity mac;

architecture Behavioral of mac is
    signal acc : signed(28 downto 0) := (others => '0'); -- 29-bit acc
begin

    -- Process that handles multiplication and accumulation
    process(clk, rst)
    begin
        if rst = '1' then
            acc <= (others => '0'); -- Reset acc to 0
        elsif rising_edge(clk) then
            if (sum_rst = '1') then 
                acc <= (others => '0');
            elsif (enable = '1') then
                acc <= acc_out; -- Add prod to acc
            end if;
        end if;
    end process;

    -- Output the acc
    acc_out <= acc + smpl * coef;

end Behavioral;