library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

entity mux4to1 is
    generic (
        DATA_WIDTH : integer := 11 -- Default width of the input data (can be changed)
    );
    Port ( 
        sel        : in  STD_LOGIC_VECTOR(1 downto 0); -- 2-bit select input to choose between 4 entries
        a          : in  signed(DATA_WIDTH-1 downto 0); -- 1st input (configurable width)
        b          : in  signed(DATA_WIDTH-1 downto 0); -- 2nd input (configurable width)
        c          : in  signed(DATA_WIDTH-1 downto 0); -- 3rd input (configurable width)
        d          : in  signed(DATA_WIDTH-1 downto 0); -- 4th input (configurable width)
        mux_out    : out signed(DATA_WIDTH-1 downto 0) -- Output with configurable width
    );
end entity mux4to1;

architecture Behavioral of mux4to1 is
begin
    process(sel, a, b, c, d)
    begin
        case sel is
            when "00" => mux_out <= a; -- Select input 'a'
            when "01" => mux_out <= b; -- Select input 'b'
            when "10" => mux_out <= c; -- Select input 'c'
            when "11" => mux_out <= d; -- Select input 'd'
            when others => mux_out <= (others => '0'); -- Default case
        end case;
    end process;
end Behavioral;